// Source file: brf/j2me/midp/dynaworks/DataStore.java
// Subsystem: dynaworks
// Module: DataStore

// Copyright (C) 2000 by Bernd R. Fix.
// You may distribute this software under the terms of the Modified
// Artistic Licence, as specified in the accompanying LICENCE.TXT file.

package brf.j2me.midp.dynaworks;

/**
 * The DataStore interface describes containers that can store key/value
 * pairs where the key is a string and the value can be any Java object.
 * The data store allows easy access to data that is shared across pages.<p>
 *
 * @author Bernd R. Fix
 * @version 1.0
 */
public interface DataStore {
    
    /**
     * set a named data object in the data store.<p>
     *
     * If there is no object associated with that name in
     * the data store, a new entry will be created and
     * linked to the data object.<p>
     * If there was a named object of the same name, it will
     * be released (overridden) by the new data object.<p>
     * The data object will be destroyed when the application
     * shuts down.<p>
     *
     *
     * @param key String - name of the data object.
     * @param value Object - data object.
     * @return boolean - successful operation?
     */
    public boolean setData (String key, Object value);
    
    /**
     * add a named data object in the data store.<p>
     *
     * If there is no object associated with that name in
     * the data store, a new "persistent" entry will be created
     * and linked to the data object.<p>
     *
     * If there was a named object of the same name, the method
     * call will fail. It will also fail if the device does
     * not support some kind of persistence mechanism.<p>
     * The data object will *NOT* be destroyed when the application
     * shuts down but is stored persistently on the device.<p>
     *
     * @param key String - name of the data object.
     * @param value Object - data object.
     * @return boolean - successful operation?
     */
    public boolean addPersistentData (String key, Object value);
    
    /**
     * drop a persistent data object.<p>
     *
     * @param key String - name of the object to be dropped.
     * @return boolean - successful operation?
     */
    public boolean dropPersistentData (String key);
    
    /**
     * get access to a named data object.<p>
     *
     * @param key String - name of the object to be retreived.
     * @return Object - data object from the store.
     */
    public Object getData (String key);
}
