// Source file: brf/j2me/midp/dynaworks/events/Event.java
// Subsystem: events
// Module: Event

// Copyright (C) 2000 by Bernd R. Fix.
// You may distribute this software under the terms of the Modified
// Artistic Licence, as specified in the accompanying LICENCE.TXT file.

package brf.j2me.midp.dynaworks.events;

// import external definitions.
import brf.j2me.midp.dynaworks.util.Point;

/**
 * The Event class represents "raw" events generated by the PalmOS event
 * loop that are passed to the application event handler 'handleSysEvent()'<p>
 *
 * @author Bernd R. Fix
 * @version 1.0
 * @see brf.j2me.midp.dynaworks.events.EventQueue
 */
public class Event {

    ////////////////////////////////////////////////////////////
    // event codes

    //----------------------------------------------------
    //	System events
    /**
       event code for idle processing.<p>
     */
    public static final int APP_IDLE    =  0;
    /**
       event code for application startup.<p>
     */
    public static final int APP_START   =  1;
    /**
       event code for device power-uo<p>
     */
    public static final int APP_PWRUP   =  2;
    /**
       event code for device shutdown<p>
     */
    public static final int APP_PWRDOWN =  3;
    /**
       event code for application termination.<p>
     */
    public static final int APP_QUIT    =  4;
    
    //----------------------------------------------------
    //	Pen events
    /**
       event code for pen touching screen.<p>
     */
    public static final int PEN_DOWN    = 10;
    /**
       event code for pen moving on screen.<p>
     */
    public static final int PEN_MOVE    = 11;
    /**
       event code for pen leaving screen.<p>
     */
    public static final int PEN_UP      = 12;

    //----------------------------------------------------
    //	Key events
    /**
       event code for character input<p>
     */
    public static final int KEY_CHAR    = 20;
    
    //----------------------------------------------------
    //	key generation events
    /**
       event code for key pressed.<p>
     */
    public static final int KEY_UP      = 21;
    /**
       event code for key repeated.<p>
     */
    public static final int KEY_REPEAT  = 22;  
    /**
       event code for key released.<p>
     */
    public static final int KEY_DOWN    = 23;  

    //----------------------------------------------------
    //	SysKey events
    /**
       event code for MENU key.<p>
     */
    public static final int KEY_MENU    = 30;
    /**
       event code for APPLIC key.<p>
     */
    public static final int KEY_APP     = 24;
    /**
       event code for BUTTON #1.<p>
     */
    public static final int KEY_BUTTON1 = 25;
    /**
       event code for BUTTON #2.<p>
     */
    public static final int KEY_BUTTON2 = 26;
    /**
       event code for BUTTON #3.<p>
     */
    public static final int KEY_BUTTON3 = 27;
    /**
       event code for BUTTON #4.<p>
     */
    public static final int KEY_BUTTON4 = 28;
    
    ////////////////////////////////////////////////////////////
    // attributes
    /**
       Event code (one of the above constants).<p>
     */
    protected int code;
    /**
       Event parameter.<p>
     */
    protected Object param;

    ////////////////////////////////////////////////////////////
    //	construction.
    /**
     * constructor.<p>
     *
     * @param code int - event code.
     */
    public Event (int code) {
        // remember the values.
        this.code = code;
        param = null;
    }
      
    //----------------------------------------------------
    /**
     * constructor.<p>
     *
     * @param code int - event code.
     * @param param int - event parameter.
     */
    public Event (int code, int param) {
        // remember the values.
        this.code = code;
        this.param = new Integer (param);
    }
    
    //----------------------------------------------------
    /**
     * constructor.<p>
     *
     * @param code int - event code.
     * @param x int - x-coordinate of (pen) event.
     * @param y int - y-coordinate of (pen) event.
     */
    public Event (int code, int x, int y) {
        // remember the values.
        this.code = code;
        param = new Point (x, y);
    }
    
    ////////////////////////////////////////////////////////////
    //	getter methods.
    /**
     * get the event code<p>
     *
     * @return int - event code
     */
    public int getCode () {
        return code;
    }
    
    //----------------------------------------------------
    /**
     * get the event parameter<p>
     *
     * @return Object - event parameter
     */
    public Object getParam () {
        return param;
    }
}
